<?php

/**
 * @file
 * Contains \Drupal\linkicon\Plugin\Field\FieldType\LinkIconItem.
 */

namespace Drupal\linkicon\Plugin\Field\FieldType;

use Drupal\link\Plugin\Field\FieldType\LinkItem;

/**
 * Plugin implementation of the 'link' field type.
 *
 * @FieldType(
 *   id = "link",
 *   label = @Translation("Link"),
 *   description = @Translation("Stores a URL string, optional varchar link text, and optional blob of attributes to assemble a link."),
 *   instance_settings = {
 *     "title" = "1"
 *   },
 *   default_widget = "link_default",
 *   default_formatter = "link"
 * )
 */
class LinkIconItem extends LinkItem {

  /**
   * {@inheritdoc}
   */
  public function instanceSettingsForm(array $form, array &$form_state) {
    $element = parent::instanceSettingsForm($form, $form_state);

    // Add our option to the title.
    if (isset($element['title']['#options'])) {
      $element['title']['#options'] += array(
        'predefined' => t('Predefined'),
      );
    }

    $element['title_predefined'] = array(
      '#type' => 'textarea',
      '#title' => t('Allowed link texts'),
      '#default_value' => $this->getSetting('title_predefined'),
      '#description' => '<p>' . t('Enter the list of key|value pairs of predefined link texts separated by new line, where key is the icon name without prefix, e.g.: <br />for <em>icon-facebook</em>, place <em>facebook|Facebook</em>. The prefix is defined at Display formatter so that you are not stuck in database when the icon vendor change prefixes from "icon-" to just "fa-", etc. Make sure the icon name is available at your icon set. To have a tooltip different from the title, add a third pipe value.<br>Warning! Pre-existing values will be reset.') . '<br><br></p>',
      '#states' => array(
        'visible' => array(
          ':input[name="instance[settings][title]"]' => array('value' => 'predefined'),
        ),
      ),
    );

    return $element;
  }
}
