<?php

/**
 * @file
 * Contains \Drupal\linkicon\Plugin\Field\FieldWidget\LinkIconWidget.
 */

namespace Drupal\linkicon\Plugin\Field\FieldWidget;

use Drupal\link\Plugin\Field\FieldWidget\LinkWidget;
use Drupal\Core\Field\FieldItemListInterface;

/**
 * Plugin implementation of the 'link' widget.
 *
 * @FieldWidget(
 *   id = "link_default",
 *   label = @Translation("Link"),
 *   field_types = {
 *     "link"
 *   },
 *   settings = {
 *     "placeholder_url" = "",
 *   }
 * )
 */
class LinkIconWidget extends LinkWidget {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, array &$form_state) {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);

    if ($this->getFieldSetting('title') == 'predefined' && $this->getFieldSetting('title_predefined')) {
      $element['title']['#type'] = 'select';
      $element['title']['#options'] = linkicon_extract_allowed_values($this->getFieldSetting('title_predefined'));
      $element['title']['#empty_option'] = t('- Select -');
      $element['title']['#access'] = TRUE;
    }

    // Post-process the title field to make it conditionally required if URL is
    // non-empty. Omit the validation on the field edit form, since the field
    // settings cannot be saved otherwise.
    $is_field_edit_form = ($element['#entity'] === NULL);
    if (!$is_field_edit_form && $this->getFieldSetting('title') == 'predefined' && $this->getFieldSetting('title_predefined')) {
      $element['#element_validate'] = array(array($this, 'validateTitle'));
    }

    return $element;
  }

  /**
   * Form element validation handler for link_field_widget_form().
   *
   * Conditionally requires the link title if a URL value was filled in, and
   * so oppositely.
   */
  function validateTitle(&$element, &$form_state, $form) {
    if ($element['url']['#value'] !== '' && $element['title']['#value'] === '') {
      form_error($element['title'], $form_state, t('!name field can not be empty if URL is provided.', array('!name' => $element['title']['#title'])));
    }
    elseif ($element['url']['#value'] === '' && $element['title']['#value'] !== '') {
      form_error($element['url'], $form_state, t('!name field can not be empty if Title is provided.', array('!name' => $element['url']['#title'])));
    }
  }
}
